@@ -6,7 +6,7 @@
 // straightforward here because of the global string cache so there is
 // no GC to worry about.
 SEXP thor_size_name;
-void thor_init() {
+void thor_init(void) {
   thor_size_name = install("size");
 }
 
@@ -20,7 +20,7 @@ static void r_mdb_dbi_finalize(SEXP r_dbi);
 static void r_mdb_cursor_finalize(SEXP r_cursor);
 static void r_thor_val_proxy_finalize(SEXP r_proxy);
 
-SEXP r_mdb_version() {
+SEXP r_mdb_version(void) {
   SEXP ret = PROTECT(allocVector(VECSXP, 1));
   setAttrib(ret, R_ClassSymbol, mkString("numeric_version"));
   SET_VECTOR_ELT(ret, 0, allocVector(INTSXP, 3));
@@ -32,7 +32,7 @@ SEXP r_mdb_version() {
   return ret;
 }
 
-SEXP r_mdb_env_create() {
+SEXP r_mdb_env_create(void) {
   MDB_env *env;
   no_error(mdb_env_create(&env), "mdb_env_create");
   return r_mdb_env_wrap(env, false);
@@ -745,7 +745,7 @@ MDB_cursor_op sexp_to_cursor_op(SEXP r_cursor_op) {
 }
 
 // --- cursor_op ---
-SEXP r_mdb_cursor_op() {
+SEXP r_mdb_cursor_op(void) {
   int n = 19;
   SEXP ret = PROTECT(allocVector(INTSXP, n));
   SEXP nms = PROTECT(allocVector(STRSXP, n));
